@@ -109,7 +109,6 @@ bonobo_generic_factory_construct (const char             *oaf_iid,
 				  GnomeFactoryCallback    factory_cb,
 				  gpointer                user_data)
 {
-	CORBA_Environment ev;
 	int ret;
 	
 	g_return_val_if_fail (c_factory != NULL, NULL);
@@ -125,13 +124,9 @@ bonobo_generic_factory_construct (const char             *oaf_iid,
 	c_factory->factory_closure = user_data;
 	c_factory->oaf_iid         = g_strdup (oaf_iid);
 
-	CORBA_exception_init (&ev);
-
 	ret = oaf_active_server_register (c_factory->oaf_iid, corba_factory);
 
-	CORBA_exception_free (&ev);
-
-	if (ret == OAF_REG_ERROR) {
+	if (ret != OAF_REG_SUCCESS) {
 		bonobo_object_unref (BONOBO_OBJECT (c_factory));
 		return NULL;
 	}
